---
title: "Rand, Aristotle, and Modern Moral Philosophy"
date: 2020-09-20T19:32:26Z
tags: ["academia","ayn rand","aristotle","ethics"]
topics: ["philosophy","psychology"]
image: /img/aristotle-vs-rand.jpg
draft: false
---

A common line of attack on Ayn Rand, from “professional” academic philosophers, is to go after her for her defense of egoism. This has always seemed disingenuous to me. Or, at best, uncharitable. The argument goes something like this:

- Ayn Rand defended selfishness as a virtue
- Thrasymachus in Plato’s Republic did the same thing
- Socrates humiliated Thrasymachus in that dialogue
- Therefore, Ayn Rand’s defense of selfishness is obviously wrong

But, anyone trained as a philosopher should be able to recognize the problems with this argument without much effort. Firstly, what does Ayn Rand mean by “selfishness”? Well, she defended a variety of “ethical egoism”, which basically means that the self is the focus of your ethics. But what does that focus amount to? Here, is where the mistake in this argument gets interesting. Thrasymachus was indeed, also an “ethical egoist”. His egoism was a variety known as *hedonic* egoism. What this means, is that the standard by which right and wrong is adjudicated comes down to whatever satisfies the most powerful person in the room, in the moment a choice is made. Is this the egoism that Ayn Rand subscribed to? In a word: NO.

According to the traditional definition, rational egoism sets the standard at “self interest”, where “self interest” is whatever rationally satisfies the needs or desires of the individual. This definition is nearly identical to hedonic egoism, because it is grounded in a utilitarian calculus in which the self is at the center, rather than the group. It’s only real difference with hedonic egoism, is that it allows for long-term consequences to factor into the decision-making judgment. This is not what Ayn Rand was talking about.

Ayn Rand’s “rational egoism” is one grounded in what she thought was “objective value” (this is part of the reason she called her philosophy “Objectivism”). She often couched her argument in terms of an opposition to altruism (the polar negative of egoism). Altruism, she argued, denied the fundamental objective value of human existence, by making the preservation of the self the standard of evil. The idea is, that any *moral obligation* (implicit or explicit) to “give a dime to a beggar”, is tantamount to a “first mortage on your life” — i.e., that you owe your existence to others, as a matter of moral law. But, if it could be shown that the value in your individual existence is self-sufficient and independent of the claims or demands of any other individual, then egoism is the proper stance.

Rand tried to make this case by way of Aristotle, and this is where her theory is actually vulnerable. But because very few modern moral philosophers have spent any time reading Aristotle, and fewer yet have read Ayn Rand, what you get from them is the high school caricature objection I outlined above.

What was Rand’s argument for the objective value of man? It borrows several elements from Aristotle’s Nicomachean Ethics. So, a bit of background is necessary to begin with. First, Aristotle’s project in the Ethics, was to account for the different kinds of living beings he observed. The first step was to identify three distinct kinds, of life: plants, animals, and humans. He made this distinction by looking at the kinds of behaviours each form of life engaged in, and grouping them as such. Plants took in sunlight, soil, and water, and grew to completion where they stood, from seed. They have a “sensory” faculty, only in the sense that they knew when to blossom, and throw new seed. Animals seemed to share this nutritive faculty with plants. However, they did much more than plants. They were able to move around, and they used their mobility to hunt for food, which they ingested for energy. They also procreated by way of sexual intercourse, and some of them nursed their young (such as horses and dogs). Both the nutritive faculty of plants and the apetitive faculty of animals is something that appeared to be present in humans, according to Aristotle. But humans also seemed to possess a special behavior not seen in plants or animals. In particular, man was capable of calculating courses of action to take, before taking them — unlike animals, which seemed driven entirely by their appetites. What’s more, man seemed uniquely capable of contemplating universal truths, and the first principles of existence. This, Aristotle called the rational principle in man.

These faculties: nutritive, appetitive, and rational, were part of the composite metaphysical being of the living things under investigation. A union of form and matter, in which the form defines what activities the being is capable of actualizing. In living things, this compound is called Hylomorphism, and is colloquially understood as the union of body and soul, where soul contains the “principle” of the living thing. Plants have a “nutritive” soul. Animals have an “appetitive” soul. Men have a “rational” soul.

For Aristotle, this distinction was not actually meant to signify a difference in *moral value*. I don’t think he would have understood what we mean when we use the term “moral value”. Instead, this was a metaphysical description. An attempt to account for what living things do, how they come into being and go out of being, and to identify what their fully actualized states were. This last point is essential, because for Aristotle, all living things are aiming at “completion”, or “perfection” (as the medievals put it). A fully perfected acorn, is an adult oak tree. A fully perfected tadpole, is a frog. A fully perfected human being, is an adult that is capable of exhibiting consistent virtue. Now, there is a larger teleological story to this. Namely, that the contemplative faculty in man’s mind must eventually find its home in the rational principle that governs the universe (the “prime mover”). Thus, there is a theodicy involved in Aristotle’s ethics, in which there is a teleological direction to everything, driven by the Divine Mind. But, this still assigned no such thing as a unique “objective value” to man.

What Ayn Rand did, was to borrow Aristotle’s distinctions, and placed them into a hierarchy of “objective” value. It’s just “objectively better” to be a rational being, than not to be, and just “objectively better” to be a living being, than a non-living being. It is tempting at this point, to raise the Humean objection. Why should man’s rational faculty be treated as the thing that gives him moral worth? Isn’t this just sticking an arbitrary flag in the ground? Why not his capacity to hold his breath under water, or his capacity to walk on two legs? I suspect Aristotle himself might have raised such an objection, if he were faced with the idea of an “objective value” which was to be assigned to a creature, based on any attribute. For Aristotle, the point of isolating attributes was to identify what *defined* the creature, not what *makes it valuable*.

But this is yet another misunderstanding of Rand’s position. She was not arguing that the rational faculty itself was what gave man his objective value. Rather, it was *a particular use of that faculty* that pointed to the existence of an objective value. Namely, man’s use of his rational faculty to evaluate. Particularly, his use of reason to identify and pursue the things he needed to preserve and perfect his life. She took the fact of the basic desire to live, as evidence of the objective value of life, and man’s capacity to reason out the means of satisfying that desire, as evidence of man’s peculiar value among living things. In short, she took the power to evaluate to be the moment of creation of objective value. Every time I apply for a job, or read a book, or eat a meal, I am reaffirming these objective values of life, and in particular, *human* life. Thus, any ethic that pitted men against men in some zero-sum equation of life-for-life, or bound men into obligations that forced them into a state of self-denial, was evil, because it was life-denying.

If this conception of value creation seems peculiarly obtuse, or perhaps even incomprehensible, you’re not alone. It’s a massive soft-spot in her ethical system. Not just because it is subject to Hume’s is-ought problem, but also because she provides no real metaphysical theory for the assignment of value at all — or rather, the elevation of the desire for life, to the state of an objective value. Rand herself is quite explicit (indeed, quite proud) of the fact that these are asserted as fundamental and incontravertable *axioms* of her theory. In other words, they cannot be explained, because they are “brute facts” of reality. So, if the “professional” philosophers were not as lazy as I suspect them of being, this might be a legitimate line of attack open to them, if they were so inclined to oppose Ayn Rand.

But they don’t do this, and there’s a good reason for it. Most of them are atheists (or agnostics). And so was Ayn Rand. Why is this important? Well, because both Plato and Aristotle offer up attempts to explain this last step. Namely, a Divine Mind. In a word: GOD. The medieval Christian church has since developed an extensive and sophisticated theology around that theory, that frankly puts Ayn Rand to shame. But it also puts most modern moral philosophers to shame as well. I’m already well over my word quota for this essay. So, I can’t go into more detail here on this point. But suffice to say, Ayn Rand’s visceral hatred for religion is something she shares with modern “humanist” philosophers, and because of this, the only objection the Humanists can offer up against Ayn Rand, is the shameless appeal to collectivist utilitarian concerns, or our natural revulsion to “selfishness”. Even Ayn Rand recognized this herself, which is why she titled her essay, “The Virtue of Selfishness”. She was trolling the Humanists.

```[Imported from exitingthecave.com on 28 November 2021]```

